
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '38.0.0rc1',
    'branch_nick': 'master',
    'revision_id': '7f986b67665c21ac40a2b32732b2f263bafd2f6c',
    'revno': 13890
}
